aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2013-09-07 19:59:15 +0200
committerSven Gothel <[email protected]>2013-09-07 19:59:15 +0200
commit9b5cee85c299e72735bebbfea5c23d3c71bc704e (patch)
treef98bfacda594aecddd9899351350b50b011c3a34 /src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java
parent4965923722fe44dfcf7eaff16cd5449707773123 (diff)
TiledPrintingAWTBase: Fix scaling - Fit frame to page, add MSAA RenderingHints test; setupPrint(Graphics2D): Query RenderingHints to use MSAA rendering
- AWTPrintLifecycle.setupPrint(Graphics2D): Query RenderingHints to use MSAA rendering - Impl. in GLCanvas - TODO GLJPanel (would need a new offscreen buffer) - TiledPrintingAWTBase: - Fix scaling - Fit frame to page - add MSAA RenderingHints test - GLCanvas: Remove dumpStack() DEBUG output
Diffstat (limited to 'src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java')
-rw-r--r--src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java b/src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java
index afa27dbd8..077ee42a9 100644
--- a/src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java
+++ b/src/jogl/classes/javax/media/opengl/awt/AWTPrintLifecycle.java
@@ -1,5 +1,3 @@
-package javax.media.opengl.awt;
-
/**
* Copyright 2013 JogAmp Community. All rights reserved.
*
@@ -27,9 +25,12 @@ package javax.media.opengl.awt;
* authors and should not be interpreted as representing official policies, either expressed
* or implied, of JogAmp Community.
*/
+package javax.media.opengl.awt;
import javax.media.opengl.GLAutoDrawable;
import java.awt.Component;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
/**
* Interface describing print lifecycle to support AWT printing
@@ -38,12 +39,13 @@ import java.awt.Component;
public interface AWTPrintLifecycle {
/**
* Shall be called before {@link Component#print(java.awt.Graphics)}.
*/
- void setupPrint();
+ void setupPrint(Graphics2D g2d);
/**
- * Shall be called after very last {@link Component#print(java.awt.Graphics)}.
+ * Shall be called after very last {@link Component#print(Graphics)}.
*/
void releasePrint();
}
@@ -38,12 +39,13 @@ import java.awt.Component;
public interface AWTPrintLifecycle {
/**
- * Shall be called before {@link Component#print(java.awt.Graphics)}.
+ * Shall be called before {@link Component#print(Graphics)}.
+ * @param g2d the {@link Graphics2D} instance, which will be used for printing.
*/